@@ -87,7 +87,7 @@ class OAuth(object):
 _etree = None
 
 
-def get_etree():  # pragma: no cover
+def get_etree():
     global _etree
     if _etree is not None:
         return _etree
@@ -155,11 +155,13 @@ def make_request(uri, headers=None, data=None, method=None,
     req.get_method = lambda: method.upper()
     try:
         resp = http.urlopen(req)
+        content = resp.read()
+        resp.close()
+        return resp, content
     except http.HTTPError as resp:
-        pass
-    content = resp.read()
-    resp.close()
-    return resp, content
+        content = resp.read()
+        resp.close()
+        return resp, content
 
 
 def add_query(url, args):
@@ -454,7 +456,7 @@ class OAuthRemoteApp(object):
         else:
             assert callback is not None, 'Callback is required OAuth2'
 
-            params = self.request_token_params or {}
+            params = dict(self.request_token_params) or {}
             client = self.make_client()
 
             scope = params.pop('scope')
