@@ -12,12 +12,12 @@ import os
 import datetime
 from functools import wraps
 from flask import request, url_for
-from flask import redirect, make_response, abort
+from flask import redirect, abort
 from werkzeug import cached_property
 from oauthlib import oauth2
 from oauthlib.oauth2 import RequestValidator, Server
 from oauthlib.common import to_unicode
-from .._utils import _extract_params, log, decode_base64
+from ..utils import extract_params, log, decode_base64, create_response
 
 __all__ = ('OAuth2Provider', 'OAuth2RequestValidator')
 
@@ -317,7 +317,7 @@ class OAuth2Provider(object):
         def decorated(*args, **kwargs):
             # raise if server not implemented
             server = self.server
-            uri, http_method, body, headers = _extract_params()
+            uri, http_method, body, headers = extract_params()
 
             if request.method == 'GET':
                 redirect_uri = request.args.get('redirect_uri', None)
@@ -358,12 +358,12 @@ class OAuth2Provider(object):
         redirect_uri = credentials.get('redirect_uri')
         log.debug('Found redirect_uri %s.', redirect_uri)
 
-        uri, http_method, body, headers = _extract_params()
+        uri, http_method, body, headers = extract_params()
         try:
             ret = server.create_authorization_response(
                 uri, http_method, body, headers, scopes, credentials)
             log.debug('Authorization successful.')
-            return redirect(ret[0])
+            return create_response(*ret)
         except oauth2.FatalClientError as e:
             return redirect(e.in_uri(self.error_uri))
         except oauth2.OAuth2Error as e:
@@ -386,16 +386,13 @@ class OAuth2Provider(object):
         @wraps(f)
         def decorated(*args, **kwargs):
             server = self.server
-            uri, http_method, body, headers = _extract_params()
+            uri, http_method, body, headers = extract_params()
             credentials = f(*args, **kwargs) or {}
             log.debug('Fetched extra credentials, %r.', credentials)
-            uri, headers, body, status = server.create_token_response(
+            ret = server.create_token_response(
                 uri, http_method, body, headers, credentials
             )
-            response = make_response(body, status)
-            for k, v in headers.items():
-                response.headers[k] = v
-            return response
+            return create_response(*ret)
         return decorated
 
     def require_oauth(self, *scopes):
@@ -407,7 +404,7 @@ class OAuth2Provider(object):
                     func()
 
                 server = self.server
-                uri, http_method, body, headers = _extract_params()
+                uri, http_method, body, headers = extract_params()
                 valid, req = server.verify_request(
                     uri, http_method, body, headers, scopes
                 )
@@ -653,6 +650,7 @@ class OAuth2RequestValidator(RequestValidator):
            datetime.datetime.utcnow() > grant.expires:
             log.debug('Grant is expired.')
             return False
+
         request.state = kwargs.get('state')
         request.user = grant.user
         request.scopes = grant.scopes
